@@ -1729,6 +1729,13 @@ sub apply {
             return 1;
         }
 
+        # support for @uri (percent-encode value)
+        if ($part eq '@uri' || $part eq '@uri()') {
+            @next_results = map { JQ::Lite::Util::_apply_uri($_) } @results;
+            @$out_ref = @next_results;
+            return 1;
+        }
+
         # support for split("separator")
         if ($part =~ /^split\((.+)\)$/) {
             my $separator = JQ::Lite::Util::_parse_string_argument($1);
